#!/usr/bin/python3

# Power off the Dome Switch from the DLI Master
#
# Copyright 2012-2018 John Kielkopf
#
#
# Assumes DLI master controller with these connections --
#
#   1  Computer System
#   2  Video Server
#   3  Telescope Controller
#   4  Apogee Camera
#   5  Telescope Auxiliary
#   6  Dome Switch 
#   7  Dome Light
#   8  Dome Charger
# 
# Based on software from Dwight Hubbard d@dhub.me
#   provided as an example on the DLI website           



import sys,time

# The module needs to be in the python path.  So we'll add the
# current directory so we can find the dli module
sys.path.append('.')

# Import the DLI module -- must be in the same directory as this py file
import dlipower

# Switch settings

SWITCHIP="136.165.99.84"
USER=""
PASSWORD=""

# Open (connect) to the power switch, if the
# parameters are not passed it defaults to the
# IP address, user and password the switch is 
# set with from the factory.  Only changed items
# actually need to be passed.
switch=dlipower.PowerSwitch(hostname=SWITCHIP,userid=USER,password=PASSWORD)

# Verify the switch
if not switch.verify():
  print("Cannot talk to the switch")
  sys.exit(1)

# Print the current state of all the outlets
switch.printstatus()
  
# Power light switch  off
switch.off(7)

# Wait the switch to initialize
time.sleep(10)

# Print the switch state
print('Dome light switch is ',switch.status(7))
